@@ -11,16 +11,18 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from time import time
-
-from supertokens_python.framework.response import BaseResponse
 import json
 from math import ceil
+from time import time
+from typing import Any, Dict, Union
+
+from supertokens_python.framework.response import BaseResponse
 
 
 class FastApiResponse(BaseResponse):
+    from fastapi import Response
 
-    def __init__(self, response):
+    def __init__(self, response: Response):
         super().__init__({})
         self.response = response
         self.original = response
@@ -28,30 +30,43 @@ class FastApiResponse(BaseResponse):
         self.response_sent = False
         self.status_set = False
 
-    def set_html_content(self, content):
+    def set_html_content(self, content: str):
         if not self.response_sent:
             self.response.body = bytes(content, "utf-8")
             self.set_header('Content-Type', 'text/html')
             self.response_sent = True
 
-    def set_cookie(self, key: str, value: str = "", max_age: int = None, expires: int = None, path: str = "/",
-                   domain: str = None, secure: bool = False, httponly: bool = False, samesite: str = "lax"):
-        # we do ceil because if we do floor, we tests may fail where the access token lifetime is set to 1 second
-        self.response.set_cookie(key, value, max_age, ceil((expires - int(time() * 1000)) / 1000), path, domain, secure,
-                                 httponly, samesite)
+    def set_cookie(self, key: str,
+                   value: str,
+                   expires: int,
+                   path: str = "/",
+                   domain: Union[str, None] = None,
+                   secure: bool = False,
+                   httponly: bool = False,
+                   samesite: str = "lax"):
+        if domain is None:
+            # we do ceil because if we do floor, we tests may fail where the access
+            # token lifetime is set to 1 second
+            self.response.set_cookie(key=key, value=value, expires=ceil((expires - int(time() * 1000)) / 1000),
+                                     path=path, secure=secure, httponly=httponly, samesite=samesite)
+        else:
+            # we do ceil because if we do floor, we tests may fail where the access
+            # token lifetime is set to 1 second
+            self.response.set_cookie(key=key, value=value, expires=ceil((expires - int(time() * 1000)) / 1000),
+                                     path=path, domain=domain, secure=secure, httponly=httponly, samesite=samesite)
 
-    def set_header(self, key, value):
+    def set_header(self, key: str, value: str):
         self.response.headers[key] = value
 
-    def get_header(self, key):
+    def get_header(self, key: str) -> Union[str, None]:
         return self.response.headers.get(key, None)
 
-    def set_status_code(self, status_code):
+    def set_status_code(self, status_code: int):
         if not self.status_set:
             self.response.status_code = status_code
             self.status_set = True
 
-    def set_json_content(self, content):
+    def set_json_content(self, content: Dict[str, Any]):
         if not self.response_sent:
             self.set_header('Content-Type', 'application/json; charset=utf-8')
             self.response.body = json.dumps(
