@@ -12,7 +12,8 @@ from ..passwordless import interfaces as PlessInterfaces
 from ..passwordless.interfaces import (CreateCodePostResponse,
                                        CreateCodeResult,
                                        CreateNewCodeForDeviceResult,
-                                       DeviceType, EmailExistsGetResponse,
+                                       DeleteUserInfoResult, DeviceType,
+                                       EmailExistsGetResponse,
                                        PhoneNumberExistsGetResponse,
                                        ResendCodePostResponse,
                                        RevokeAllCodesResult, RevokeCodeResult,
@@ -134,6 +135,14 @@ class RecipeInterface(ABC):
                                        email: Union[str, None], phone_number: Union[str, None], user_context: Dict[str, Any]) -> UpdateUserResult:
         pass
 
+    @abstractmethod
+    async def delete_email_for_passwordless_user(self, user_id: str, user_context: Dict[str, Any]) -> DeleteUserInfoResult:
+        pass
+
+    @abstractmethod
+    async def delete_phone_number_for_user(self, user_id: str, user_context: Dict[str, Any]) -> DeleteUserInfoResult:
+        pass
+
     @abstractmethod
     async def revoke_all_codes(self,
                                email: Union[str, None], phone_number: Union[str, None], user_context: Dict[str, Any]) -> RevokeAllCodesResult:
